@@ -11,7 +11,7 @@ import time
 from gettext import gettext as _
 from typing import cast
 
-from gi.repository import Gio, GLib, GObject, Gtk
+from gi.repository import Gio, GLib, Gtk
 
 from lutris import settings
 from lutris.config import LutrisConfig
@@ -20,28 +20,40 @@ from lutris.database import games as games_db
 from lutris.database import sql
 from lutris.exception_backstops import watch_game_errors
 from lutris.exceptions import GameConfigError, InvalidGameMoveError, MissingExecutableError
+from lutris.gui.widgets import NotificationSource
 from lutris.installer import InstallationKind
 from lutris.monitored_command import MonitoredCommand
 from lutris.runner_interpreter import export_bash_script, get_launch_parameters
 from lutris.runners import import_runner, is_valid_runner_name
-from lutris.runners.runner import Runner
-from lutris.util import discord, extract, jobs, linux, strings, system, xdgshortcuts
-from lutris.util.display import DISPLAY_MANAGER, SCREEN_SAVER_INHIBITOR, disable_compositing, enable_compositing
+from lutris.runners.runner import Runner, kill_processes
+from lutris.util import busy, discord, extract, jobs, linux, strings, system, xdgshortcuts
+from lutris.util.display import (
+    DISPLAY_MANAGER,
+    SCREEN_SAVER_INHIBITOR,
+    disable_compositing,
+    enable_compositing,
+    is_display_x11,
+)
 from lutris.util.graphics.xephyr import get_xephyr_command
 from lutris.util.graphics.xrandr import turn_off_except
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import LOG_BUFFERS, logger
-from lutris.util.process import Process
 from lutris.util.steam.shortcut import remove_shortcut as remove_steam_shortcut
 from lutris.util.system import fix_path_case
 from lutris.util.timer import Timer
-from lutris.util.wine import proton
 from lutris.util.yaml import write_yaml_to_file
 
 HEARTBEAT_DELAY = 2000
 
+GAME_START = NotificationSource()
+GAME_STARTED = NotificationSource()
+GAME_STOPPED = NotificationSource()
+GAME_UPDATED = NotificationSource()
+GAME_INSTALLED = NotificationSource()
+GAME_UNHANDLED_ERROR = NotificationSource()
 
-class Game(GObject.Object):
+
+class Game:
     """This class takes cares of loading the configuration for a game
     and running it.
     """
@@ -54,20 +66,11 @@ class Game(GObject.Object):
 
     PRIMARY_LAUNCH_CONFIG_NAME = "(primary)"
 
-    __gsignals__ = {
-        # SIGNAL_RUN_LAST works around bug https://gitlab.gnome.org/GNOME/glib/-/issues/513
-        # fix merged Dec 2020, but we support older GNOME!
-        "game-error": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
-        "game-unhandled-error": (GObject.SIGNAL_RUN_FIRST, None, (object,)),
-        "game-start": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-started": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-stopped": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-updated": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-installed": (GObject.SIGNAL_RUN_FIRST, None, ()),
-    }
-
     def __init__(self, game_id: str = None):
         super().__init__()
+
+        self.game_error = NotificationSource()
+
         self._id = str(game_id) if game_id else None  # pylint: disable=invalid-name
 
         # Load attributes from database
@@ -92,7 +95,12 @@ class Game(GObject.Object):
             self.custom_images.add("coverart_big")
         self.service = game_data.get("service")
         self.appid = game_data.get("service_id")
-        self.playtime = float(game_data.get("playtime") or 0.0)
+        try:
+            self.playtime = float(game_data.get("playtime") or 0.0)
+        except ValueError as ex:
+            logger.exception("Unable to parse playtime '%s' for game %s: %s", game_data.get("playtime"), self.slug, ex)
+            self.playtime = 0.0
+
         self.discord_id = game_data.get("discord_id")  # Discord App ID for RPC
 
         self._config = None
@@ -169,14 +177,14 @@ class Game(GObject.Object):
         for removed_category_name in removed_category_names:
             self.remove_category(removed_category_name, no_signal=True)
 
-        self.emit("game-updated")
+        GAME_UPDATED.fire(self)
 
     def add_category(self, category_name, no_signal=False):
         """add game to category"""
         if not self.is_db_stored:
             raise RuntimeError("Games that do not have IDs cannot belong to categories.")
 
-        category = categories_db.get_category(category_name)
+        category = categories_db.get_category_by_name(category_name)
         if category is None:
             category_id = categories_db.add_category(category_name)
         else:
@@ -184,21 +192,21 @@ class Game(GObject.Object):
         categories_db.add_game_to_category(self.id, category_id)
 
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
     def remove_category(self, category_name, no_signal=False):
         """remove game from category"""
         if not self.is_db_stored:
             return
 
-        category = categories_db.get_category(category_name)
+        category = categories_db.get_category_by_name(category_name)
         if category is None:
             return
         category_id = category["id"]
         categories_db.remove_category_from_game(self.id, category_id)
 
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
     @property
     def is_favorite(self) -> bool:
@@ -248,16 +256,16 @@ class Game(GObject.Object):
         return strings.get_formatted_playtime(self.playtime)
 
     def signal_error(self, error):
-        """Reports an error by firing game-error. If handled, it returns
-        True to indicate it handled it, and that's it. If not, this fires
-        game-unhandled-error, which is actually handled via an emission hook
-        and should not be connected otherwise.
+        """Reports an error by firing game_error. If there is no handler for this,
+        we fall back to the global GAME_UNHANDLED_ERROR.
 
         This allows special error handling to be set up for a particular Game, but
-        there's always some handling."""
-        handled = self.emit("game-error", error)
-        if not handled:
-            self.emit("game-unhandled-error", error)
+        there's always some global handling."""
+
+        if self.game_error.has_handlers:
+            self.game_error.fire(error)
+        else:
+            GAME_UNHANDLED_ERROR.fire(self, error)
 
     def get_browse_dir(self):
         """Return the path to open with the Browse Files action."""
@@ -347,7 +355,9 @@ class Game(GObject.Object):
         service = launch_ui_delegate.get_service(self.service)
         db_game = service.get_service_db_game(self)
         if not db_game:
-            logger.error("Can't find %s for %s", self.name, service.name)
+            logger.error("Can't find %s for %s, trying to fall back to Lutris installers", self.name, service.name)
+            application = Gio.Application.get_default()
+            application.show_lutris_installer_window(game_slug=self.slug)
             return
 
         try:
@@ -358,12 +368,11 @@ class Game(GObject.Object):
 
         if game_id:
 
-            def on_error(_game, error):
+            def on_error(error: BaseException) -> None:
                 logger.exception("Unable to install game: %s", error)
-                return True
 
             game = Game(game_id)
-            game.connect("game-error", on_error)
+            game.game_error.register(on_error)
             game.launch(launch_ui_delegate)
 
     def install_updates(self, install_ui_delegate):
@@ -382,7 +391,7 @@ class Game(GObject.Object):
                 installers, service, self.appid, installation_kind=InstallationKind.UPDATE
             )
 
-        jobs.AsyncCall(service.get_update_installers, on_installers_ready, db_game)
+        busy.BusyAsyncCall(service.get_update_installers, on_installers_ready, db_game)
         return True
 
     def install_dlc(self, install_ui_delegate):
@@ -399,7 +408,7 @@ class Game(GObject.Object):
             application = Gio.Application.get_default()
             application.show_installer_window(installers, service, self.appid, installation_kind=InstallationKind.DLC)
 
-        jobs.AsyncCall(service.get_dlc_installers_runner, on_installers_ready, db_game, db_game["runner"])
+        busy.BusyAsyncCall(service.get_dlc_installers_runner, on_installers_ready, db_game, db_game["runner"])
         return True
 
     def uninstall(self, delete_files: bool = False) -> None:
@@ -476,19 +485,19 @@ class Game(GObject.Object):
         }
         self._id = str(games_db.add_or_update(**game_data))
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
     def save_platform(self):
         """Save only the platform field- do not restore any other values the user may have changed
         in another window."""
         games_db.update_existing(id=self.id, slug=self.slug, platform=self.platform)
-        self.emit("game-updated")
+        GAME_UPDATED.fire(self)
 
     def save_lastplayed(self):
         """Save only the lastplayed field- do not restore any other values the user may have changed
         in another window."""
         games_db.update_existing(id=self.id, slug=self.slug, lastplayed=self.lastplayed, playtime=self.playtime)
-        self.emit("game-updated")
+        GAME_UPDATED.fire(self)
 
     def check_launchable(self):
         """Verify that the current game can be launched, and raises exceptions if not."""
@@ -655,7 +664,7 @@ class Game(GObject.Object):
     def get_store_name(self) -> str:
         store = self.service
         if not store:
-            return ""
+            return "none"
         if self.service == "humblebundle":
             return "humble"
         return store
@@ -670,10 +679,7 @@ class Game(GObject.Object):
             return False
         command, env = get_launch_parameters(self.runner, gameplay_info)
 
-        if env.get("WINEARCH") == "win32" and "umu" in " ".join(command):
-            raise RuntimeError("Proton is not compatible with 32bit prefixes")
-        env["GAMEID"] = proton.get_game_id(self)
-        env["STORE"] = self.get_store_name()
+        env["STORE"] = env.get("STORE") or self.get_store_name()
 
         # Some environment variables for the use of custom pre-launch and post-exit scripts.
         env["GAME_NAME"] = self.name
@@ -692,7 +698,7 @@ class Game(GObject.Object):
             self.game_runtime_config["working_dir"] = gameplay_info["working_dir"]
 
         # Input control
-        if self.runner.system_config.get("use_us_layout"):
+        if self.runner.system_config.get("use_us_layout") and is_display_x11():
             system.set_keyboard_layout("us")
 
         # Display control
@@ -717,6 +723,8 @@ class Game(GObject.Object):
         if xephyr != "off":
             env["DISPLAY"] = self.start_xephyr()
 
+        self.runner.finish_env(env, self)
+
         antimicro_config = self.runner.system_config.get("antimicro_config")
         if system.path_exists(antimicro_config):
             self.start_antimicrox(antimicro_config)
@@ -753,7 +761,7 @@ class Game(GObject.Object):
             logger.error("No prelaunch PIDs could be obtained. Game stop may be ineffective.")
             self.prelaunch_pids = None
 
-        self.emit("game-start")
+        GAME_START.fire(self)
 
         @watch_game_errors(game_stop_result=False, game=self)
         def configure_game(_ignored, error):
@@ -783,7 +791,7 @@ class Game(GObject.Object):
         self.game_thread.start()
         self.timer.start()
         self.state = self.STATE_RUNNING
-        self.emit("game-started")
+        GAME_STARTED.fire(self)
 
         # Game is running, let's update discord status
         if settings.read_setting("discord_rpc") == "True" and self.discord_id:
@@ -800,7 +808,7 @@ class Game(GObject.Object):
         # If force_stop_game fails, wait a few seconds and try SIGKILL on any survivors
 
         def force_stop_game():
-            self.runner.force_stop_game(self)
+            self.runner.force_stop_game(self.get_stop_pids())
             return not self.get_stop_pids()
 
         def force_stop_game_cb(all_dead, error):
@@ -811,7 +819,7 @@ class Game(GObject.Object):
             else:
                 self.force_kill_delayed()
 
-        jobs.AsyncCall(force_stop_game, force_stop_game_cb)
+        busy.BusyAsyncCall(force_stop_game, force_stop_game_cb)
 
     def force_kill_delayed(self, death_watch_seconds=5, death_watch_interval_seconds=0.5):
         """Forces termination of a running game, but only after a set time has elapsed;
@@ -825,7 +833,7 @@ class Game(GObject.Object):
                     return
 
             # Once we get past the time limit, starting killing!
-            self.kill_processes(signal.SIGKILL)
+            kill_processes(signal.SIGKILL, self.get_stop_pids())
 
         def death_watch_cb(_result, error):
             """Called after the death watch to more firmly kill any survivors."""
@@ -835,19 +843,7 @@ class Game(GObject.Object):
             # If we still can't kill everything, we'll still say we stopped it.
             self.stop_game()
 
-        jobs.AsyncCall(death_watch, death_watch_cb)
-
-    def kill_processes(self, sig):
-        """Sends a signal to a process list, logging errors."""
-        pids = self.get_stop_pids()
-
-        for pid in pids:
-            try:
-                os.kill(int(pid), sig)
-            except ProcessLookupError as ex:
-                logger.debug("Failed to kill game process: %s", ex)
-            except PermissionError:
-                logger.debug("Permission to kill process %s denied", pid)
+        busy.BusyAsyncCall(death_watch, death_watch_cb)
 
     def get_stop_pids(self):
         """Finds the PIDs of processes that need killin'!"""
@@ -864,18 +860,8 @@ class Game(GObject.Object):
             return set()
 
         new_pids = self.get_new_pids()
-
         game_folder = self.resolve_game_path()
-        folder_pids = set()
-        for pid in new_pids:
-            cmdline = Process(pid).cmdline or ""
-            # pressure-vessel: This could potentially pick up PIDs not started by lutris?
-            if game_folder in cmdline or "pressure-vessel" in cmdline:
-                folder_pids.add(pid)
-
-        uuid_pids = set(pid for pid in new_pids if Process(pid).environ.get("LUTRIS_GAME_UUID") == self.game_uuid)
-
-        return folder_pids & uuid_pids
+        return self.runner.filter_game_pids(new_pids, self.game_uuid, game_folder)
 
     def get_new_pids(self):
         """Return list of PIDs started since the game was launched"""
@@ -894,7 +880,7 @@ class Game(GObject.Object):
             # Inspect why it could have crashed
 
         self.state = self.STATE_STOPPED
-        self.emit("game-stopped")
+        GAME_STOPPED.fire(self)
         if os.path.exists(self.now_playing_path):
             os.unlink(self.now_playing_path)
         if not self.timer.finished:
@@ -998,7 +984,11 @@ class Game(GObject.Object):
 
         # Clear Discord Client Status
         if settings.read_setting("discord_rpc") == "True" and self.discord_id:
-            discord.client.clear()
+            try:
+                discord.client.clear()
+            except:
+                # Shut up no one cares about you or your errors
+                pass
 
         self.process_return_codes()
 
@@ -1031,7 +1021,7 @@ class Game(GObject.Object):
         old_location = self.directory
         target_directory = self._get_move_target_directory(new_location)
 
-        if new_location.startswith(old_location):
+        if old_location and system.path_contains(old_location, new_location):
             raise InvalidGameMoveError(
                 _("Lutris can't move '%s' to a location inside of itself, '%s'.") % (old_location, new_location)
             )
@@ -1039,6 +1029,12 @@ class Game(GObject.Object):
         self.directory = target_directory
         self.save(no_signal=no_signal)
 
+        if not old_location:
+            # We can't move or update the config without an initial
+            # location, but no-one expects us to. We've just updated
+            # the game directory, and that will do.
+            return target_directory
+
         with open(self.config.game_config_path, encoding="utf-8") as config_file:
             for line in config_file.readlines():
                 if target_directory in line:
