@@ -1,4 +1,5 @@
 from gettext import gettext as _
+from typing import Optional
 
 from gi.repository import Gdk, Gtk
 
@@ -6,11 +7,18 @@ from lutris.exceptions import UnavailableRunnerError
 from lutris.game import Game
 from lutris.gui import dialogs
 from lutris.gui.dialogs.download import DownloadDialog
-from lutris.runners import wine
+from lutris.services import get_enabled_services
 from lutris.util.downloader import Downloader
 
 
-class LaunchUIDelegate:
+class Delegate:
+    def get_service(self, service_id):
+        """Returns a new service object by its id. This seems dumb, but it is a work-around
+        for Python's circular import limitations."""
+        return get_enabled_services()[service_id]()
+
+
+class LaunchUIDelegate(Delegate):
     """These objects provide UI for the game while it is being launched;
     one provided to the launch() method.
 
@@ -30,7 +38,7 @@ class LaunchUIDelegate:
         actual checks.
         """
         if not game.runner.is_installed():
-            raise UnavailableRunnerError("The required runner '%s' is not installed." % game.runner.name)
+            raise UnavailableRunnerError(_("The required runner '%s' is not installed.") % game.runner.name)
         return True
 
     def select_game_launch_config(self, game):
@@ -43,7 +51,7 @@ class LaunchUIDelegate:
         return {}  # primary game
 
 
-class InstallUIDelegate:
+class InstallUIDelegate(Delegate):
     """These objects provide UI for a runner as it is installing itself.
     One of these must be provided to the install() method.
 
@@ -52,13 +60,13 @@ class InstallUIDelegate:
     ask the user questions. Windows then inherit from DialogLaunchUIDelegate.
     """
 
-    def show_install_yesno_inquiry(self, question, title):
+    def show_install_yesno_inquiry(self, question: str, title: str) -> bool:
         """Called to ask the user a yes/no question.
 
         The default is 'yes'."""
         return True
 
-    def show_install_file_inquiry(self, question, title, message):
+    def show_install_file_inquiry(self, question: str, title: str, message: str) -> Optional[str]:
         """Called to ask the user for a file.
 
         Lutris first asks the user the question given (showing the title);
@@ -71,7 +79,7 @@ class InstallUIDelegate:
         """
         return None
 
-    def download_install_file(self, url, destination):
+    def download_install_file(self, url: str, destination: str) -> Downloader:
         """Downloads a file from a URL to a destination, overwriting any
         file at that path.
 
@@ -108,19 +116,23 @@ class DialogInstallUIDelegate(InstallUIDelegate):
     """This provides UI for runner installation via dialogs."""
 
     def show_install_yesno_inquiry(self, question, title):
-        dialog = dialogs.QuestionDialog({
-            "parent": self,
-            "question": question,
-            "title": title,
-        })
+        dialog = dialogs.QuestionDialog(
+            {
+                "parent": self,
+                "question": question,
+                "title": title,
+            }
+        )
         return Gtk.ResponseType.YES == dialog.result
 
     def show_install_file_inquiry(self, question, title, message):
-        dlg = dialogs.QuestionDialog({
-            "parent": self,
-            "question": question,
-            "title": title,
-        })
+        dlg = dialogs.QuestionDialog(
+            {
+                "parent": self,
+                "question": question,
+                "title": title,
+            }
+        )
         if dlg.result == dlg.YES:
             dlg = dialogs.FileDialog(message)
             return dlg.filename
@@ -140,10 +152,6 @@ class DialogLaunchUIDelegate(LaunchUIDelegate):
             if not installed:
                 return False
 
-        if "wine" in game.runner_name and not wine.get_system_wine_version():
-            dialogs.WineNotInstalledWarning(parent=self)
-            return False
-
         return True
 
     def select_game_launch_config(self, game):
@@ -196,12 +204,7 @@ class DialogLaunchUIDelegate(LaunchUIDelegate):
             config_index = get_preferred_config_index()
 
         if config_index is None:
-            dlg = dialogs.LaunchConfigSelectDialog(
-                game,
-                configs,
-                title=_("Select game to launch"),
-                parent=self
-            )
+            dlg = dialogs.LaunchConfigSelectDialog(game, configs, title=_("Select game to launch"), parent=self)
             if not dlg.confirmed:
                 return None  # no error here- the user cancelled out
 
