@@ -4,6 +4,7 @@ from gi.repository import Gtk
 
 from lutris.gui.dialogs import ModalDialog
 from lutris.gui.widgets.download_progress_box import DownloadProgressBox
+from lutris.util.downloader import Downloader
 
 
 class DownloadDialog(ModalDialog):
@@ -12,30 +13,28 @@ class DownloadDialog(ModalDialog):
     def __init__(self, url=None, dest=None, title=None, label=None, downloader=None, parent=None):
         super().__init__(title=title or _("Downloading file"), parent=parent, border_width=10)
         self.set_size_request(485, 104)
-        params = {"url": url, "dest": dest, "title": label or _("Downloading %s") % url}
-        self.dialog_progress_box = DownloadProgressBox(params, downloader=downloader)
+        self.dialog_progress_box = DownloadProgressBox(
+            url=url, dest=dest, title=label or _("Downloading %s") % url, downloader=downloader
+        )
 
         self.dialog_progress_box.connect("complete", self.download_complete)
         self.dialog_progress_box.connect("cancel", self.download_cancelled)
-        self.connect("response", self.on_response)
 
         self.get_content_area().add(self.dialog_progress_box)
         self.show_all()
         self.dialog_progress_box.start()
 
     @property
-    def downloader(self):
+    def downloader(self) -> Downloader:
         return self.dialog_progress_box.downloader
 
     def download_complete(self, _widget, _data):
         self.response(Gtk.ResponseType.OK)
-        self.destroy()
 
     def download_cancelled(self, _widget):
         self.response(Gtk.ResponseType.CANCEL)
-        self.destroy()
 
-    def on_response(self, _dialog, response):
-        if response == Gtk.ResponseType.DELETE_EVENT:
-            self.dialog_progress_box.downloader.cancel()
-            self.destroy()
+    def on_response(self, dialog, response):
+        if response in (Gtk.ResponseType.DELETE_EVENT, Gtk.ResponseType.CANCEL):
+            self.dialog_progress_box.cancel_download()
+        super().on_response(dialog, response)
