@@ -1,4 +1,5 @@
 """Move hidden games from settings to database"""
+
 from lutris import settings
 from lutris.game import Game
 
@@ -6,11 +7,8 @@ from lutris.game import Game
 def get_hidden_ids():
     """Return a list of game IDs to be excluded from the library view"""
     # Load the ignore string and filter out empty strings to prevent issues
-    ignores_raw = settings.read_setting("library_ignores", section="lutris", default="").split(",")
-    ignores = [ignore for ignore in ignores_raw if not ignore == ""]
-
-    # Turn the strings into integers
-    return [int(game_id) for game_id in ignores]
+    ignores_raw = settings.read_setting("library_ignores").split(",")
+    return [ignore.strip() for ignore in ignores_raw if ignore]
 
 
 def migrate():
@@ -22,5 +20,5 @@ def migrate():
         return []
     for game_id in game_ids:
         game = Game(game_id)
-        game.set_hidden(True)
-    settings.write_setting("library_ignores", '', section="lutris")
+        game.mark_as_hidden(True)
+    settings.write_setting("library_ignores", "", section="lutris")
