@@ -1,4 +1,5 @@
 """Run web based games"""
+
 import os
 import string
 from gettext import gettext as _
@@ -6,6 +7,7 @@ from urllib.parse import urlparse
 
 from lutris import settings
 from lutris.database.games import get_game_by_field
+from lutris.exceptions import GameConfigError
 from lutris.runners.runner import Runner
 from lutris.util import datapath, linux, resources, system
 from lutris.util.strings import split_arguments
@@ -74,8 +76,7 @@ class web(Runner):
             "label": _("Disable menu bar and default shortcuts"),
             "type": "bool",
             "default": False,
-            "help": _("This also disables default keyboard shortcuts, "
-                      "like copy/paste and fullscreen toggling."),
+            "help": _("This also disables default keyboard shortcuts, " "like copy/paste and fullscreen toggling."),
         },
         {
             "option": "disable_scrolling",
@@ -89,8 +90,7 @@ class web(Runner):
             "label": _("Hide mouse cursor"),
             "type": "bool",
             "default": False,
-            "help": _("Prevents the mouse cursor from showing "
-                      "when hovering above the window."),
+            "help": _("Prevents the mouse cursor from showing " "when hovering above the window."),
         },
         {
             "option": "open_links",
@@ -107,8 +107,7 @@ class web(Runner):
             "label": _("Remove default <body> margin & padding"),
             "type": "bool",
             "default": False,
-            "help": _("Sets margin and padding to zero "
-                      "on &lt;html&gt; and &lt;body&gt; elements."),
+            "help": _("Sets margin and padding to zero " "on &lt;html&gt; and &lt;body&gt; elements."),
         },
         {
             "option": "enable_flash",
@@ -141,26 +140,19 @@ class web(Runner):
             "help": _("Launch the game in a web browser."),
         },
         {
-            "option":
-            "custom_browser_executable",
-            "label":
-            _("Custom web browser executable"),
-            "type":
-            "file",
+            "option": "custom_browser_executable",
+            "label": _("Custom web browser executable"),
+            "type": "file",
             "help": _(
                 "Select the executable of a browser on your system.\n"
                 "If left blank, Lutris will launch your default browser (xdg-open)."
             ),
         },
         {
-            "option":
-            "custom_browser_args",
-            "label":
-            _("Web browser arguments"),
-            "type":
-            "string",
-            "default":
-            '"$GAME"',
+            "option": "custom_browser_args",
+            "label": _("Web browser arguments"),
+            "type": "string",
+            "default": '"$GAME"',
             "help": _(
                 "Command line arguments to pass to the executable.\n"
                 "$GAME or $URL inserts the game url.\n\n"
@@ -181,22 +173,14 @@ class web(Runner):
     def play(self):
         url = self.game_config.get("main_file")
         if not url:
-            return {
-                "error": "CUSTOM",
-                "text": _("The web address is empty, \n"
-                          "verify the game's configuration."),
-            }
+            raise GameConfigError(_("The web address is empty, \n" "verify the game's configuration."))
 
         # check if it's an url or a file
         is_url = urlparse(url).scheme != ""
 
         if not is_url:
             if not system.path_exists(url):
-                return {
-                    "error": "CUSTOM",
-                    "text": _("The file %s does not exist, \n"
-                              "verify the game's configuration.") % url,
-                }
+                raise GameConfigError(_("The file %s does not exist, \n" "verify the game's configuration.") % url)
             url = "file://" + url
 
         game_data = get_game_by_field(self.config.game_config_id, "configpath")
@@ -253,7 +237,7 @@ class web(Runner):
         if self.runner_config.get("user_agent"):
             command.append("--user-agent")
             command.append(self.runner_config.get("user_agent"))
-        if linux.LINUX_SYSTEM.is_flatpak:
+        if linux.LINUX_SYSTEM.is_flatpak():
             command.append("--no-sandbox")
 
         return {"command": command, "env": self.get_env(False)}
