@@ -2,7 +2,6 @@ import os
 
 from lutris.config import write_game_config
 from lutris.database.games import add_game, get_games
-from lutris.game import Game
 from lutris.util.log import logger
 from lutris.util.retroarch.core_config import RECOMMENDED_CORES
 from lutris.util.strings import slugify
@@ -31,15 +30,11 @@ ROM_FLAGS = [
     "F",
     "U",
     "E",
-    "UE"
-    "W",
-    "M3"
+    "UE" "W",
+    "M3",
 ]
 
-EXTRA_FLAGS = [
-    "!",
-    "S"
-]
+EXTRA_FLAGS = ["!", "S"]
 
 
 def clean_rom_name(name):
@@ -71,17 +66,11 @@ def scan_directory(dirname):
         logger.info("Importing '%s'", name)
         slug = slugify(name)
         core = core_matches[ext]
-        config = {
-            "game": {
-                "core": core_matches[ext],
-                "main_file": os.path.join(dirname, filename)
-            }
-        }
+        config = {"game": {"core": core_matches[ext], "main_file": os.path.join(dirname, filename)}}
         installer_slug = "%s-libretro-%s" % (slug, core)
         existing_game = get_games(filters={"installer_slug": installer_slug})
         if existing_game:
-            game = Game(existing_game[0]["id"])
-            game.remove()
+            continue
         configpath = write_game_config(slug, config)
         game_id = add_game(
             name=name,
@@ -90,7 +79,7 @@ def scan_directory(dirname):
             directory=dirname,
             installed=1,
             installer_slug=installer_slug,
-            configpath=configpath
+            configpath=configpath,
         )
         added_games.append(game_id)
     return added_games
