@@ -3,9 +3,10 @@
 import os
 import shutil
 from gettext import gettext as _
-from typing import List
+from pathlib import Path
+from typing import Any, Dict, List
 
-from gi.repository import Gio, GObject
+from gi.repository import Gio
 
 from lutris import api, settings
 from lutris.api import get_game_installers
@@ -13,13 +14,15 @@ from lutris.config import write_game_config
 from lutris.database import sql
 from lutris.database.games import add_game, get_game_by_field, get_game_for_service, get_games
 from lutris.database.services import ServiceGameCollection
-from lutris.game import Game
+from lutris.game import GAME_UPDATED, Game
 from lutris.gui.dialogs import NoticeDialog
-from lutris.gui.dialogs.webconnect_dialog import DEFAULT_USER_AGENT, WebConnectDialog
+from lutris.gui.dialogs.webconnect_dialog import WebConnectDialog
 from lutris.gui.views.media_loader import download_media
+from lutris.gui.widgets import NotificationSource
 from lutris.gui.widgets.utils import BANNER_SIZE, ICON_SIZE
 from lutris.services.service_media import ServiceMedia
 from lutris.util import system
+from lutris.util.busy import BusyAsyncCall
 from lutris.util.cookies import WebkitCookieJar
 from lutris.util.jobs import AsyncCall
 from lutris.util.log import logger
@@ -69,7 +72,13 @@ class LutrisCoverartMedium(LutrisCoverart):
     size = (176, 234)
 
 
-class BaseService(GObject.Object):
+SERVICE_GAMES_LOADING = NotificationSource()
+SERVICE_GAMES_LOADED = NotificationSource()
+SERVICE_LOGIN = NotificationSource()
+SERVICE_LOGOUT = NotificationSource()
+
+
+class BaseService:
     """Base class for local services"""
 
     id = NotImplemented
@@ -88,13 +97,6 @@ class BaseService(GObject.Object):
     default_format = "icon"
     is_loading = False
 
-    __gsignals__ = {
-        "service-games-load": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "service-games-loaded": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "service-login": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "service-logout": (GObject.SIGNAL_RUN_FIRST, None, ()),
-    }
-
     @property
     def matcher(self):
         if self._matcher:
@@ -142,14 +144,16 @@ class BaseService(GObject.Object):
                 self.load()
                 self.load_icons()
                 self.add_installed_games()
+                logger.debug("'%s' games reloaded", self.name)
             finally:
                 self.is_loading = False
 
         def reload_cb(_result, error):
-            self.emit("service-games-loaded")
+            logger.debug("Reload callback")
+            SERVICE_GAMES_LOADED.fire(self)
             reloaded_callback(error)
 
-        self.emit("service-games-load")
+        SERVICE_GAMES_LOADING.fire(self)
         AsyncCall(do_reload, reload_cb)
 
     def load(self):
@@ -157,6 +161,7 @@ class BaseService(GObject.Object):
 
     def load_icons(self):
         """Download all game media from the service"""
+        logger.debug("Loading icons...")
         all_medias = self.medias.copy()
         all_medias.update(self.extra_medias)
 
@@ -178,10 +183,17 @@ class BaseService(GObject.Object):
     def get_update_installers(self, db_game):
         return []
 
-    def generate_installer(self, db_game):
+    def generate_installer(self, db_game: Dict[str, Any]) -> Dict[str, Any]:
         """Used to generate an installer from the data returned from the services"""
         return {}
 
+    def generate_installers(self, db_game: Dict[str, Any]) -> List[dict]:
+        """Used to generate a list of installers to choose from, from the data returned from the services
+        By default this is just the installer from generate_installer(), and if overridden to return
+        more than one, then generate_installer must be overridden ti pick a default installer."""
+        installer = self.generate_installer(db_game)
+        return [installer] if installer else []
+
     def install_from_api(self, db_game, appid=None):
         """Install a game, using the API or generate_installer() to obtain the installer."""
         if not appid:
@@ -192,11 +204,11 @@ class BaseService(GObject.Object):
                 raise error  # bounce any error off the backstop
 
             if not service_installers:
-                service_installers = [self.generate_installer(db_game)]
+                service_installers = self.generate_installers(db_game)
             application = Gio.Application.get_default()
             application.show_installer_window(service_installers, service=self, appid=appid)
 
-        AsyncCall(self.get_installers_from_api, on_installers_ready, appid)
+        BusyAsyncCall(self.get_installers_from_api, on_installers_ready, appid)
 
     def get_installer_files(self, installer, installer_file_id, selected_extras):
         """Used to obtains the content files from the service, when an 'N/A' file is left in
@@ -297,11 +309,12 @@ class BaseService(GObject.Object):
             if existing_game:
                 logger.debug("Found existing game, aborting install")
                 return None, None, existing_game
-        installer = self.generate_installer(db_game) if not update else None
-        if installer:
+        installers = self.generate_installers(db_game) if not update else []
+        if installers:
             if service_installers:
-                installer["version"] = installer["version"] + " (auto-generated)"
-            service_installers.append(installer)
+                for installer in installers:
+                    installer["version"] = installer["version"] + " (auto-generated)"
+            service_installers.extend(installers)
         if not service_installers:
             logger.error("No installer found for %s", db_game)
             return
@@ -324,7 +337,7 @@ class BaseService(GObject.Object):
         # be added without going through an install dialog.
         if self.local:
             return self.simple_install(db_game)
-        AsyncCall(self.get_service_installers, self.on_service_installers_loaded, db_game, update)
+        BusyAsyncCall(self.get_service_installers, self.on_service_installers_loaded, db_game, update)
 
     def install_by_id(self, appid):
         """Installs a game given the appid for the game on this service."""
@@ -343,7 +356,7 @@ class BaseService(GObject.Object):
         # If an existing game was found, it may have been updated,
         # and it's not safe to fire this until we get here.
         if existing_game:
-            existing_game.emit("game-updated")
+            GAME_UPDATED.fire(existing_game)
 
         if service_installers and db_game:
             application = Gio.Application.get_default()
@@ -397,6 +410,17 @@ class BaseService(GObject.Object):
             return ServiceGameCollection.get_game(self.id, game.appid)
         return None
 
+    def get_game_release_date(self, db_game: dict):
+        """Services can implement this method so games that are not in the
+        database can be sorted by release date (Year) based on service data."""
+
+    def get_game_release_year(self, db_game: dict):
+        """Returns game release year
+        Does not have to be rewritten if get_game_release_date returns
+        rfc/iso compatible date (YYYY-MM-DD)"""
+        date = self.get_game_release_date(db_game)
+        return date[:4] if date else ""
+
 
 class OnlineService(BaseService):
     """Base class for online gaming services"""
@@ -406,9 +430,10 @@ class OnlineService(BaseService):
     cache_path = NotImplemented
     requires_login_page = False
 
+    login_url = NotImplemented
     login_window_width = 390
     login_window_height = 500
-    login_user_agent = DEFAULT_USER_AGENT
+    login_user_agent = settings.DEFAULT_USER_AGENT
 
     @property
     def credential_files(self):
@@ -431,8 +456,33 @@ class OnlineService(BaseService):
         dialog = WebConnectDialog(self, parent)
         dialog.run()
 
+    @property
+    def is_login_in_progress(self) -> bool:
+        """Set to true if the login process is underway; the credential files make be created at this
+        time, but that does not count as 'authenticated' until the login process is over. This is used
+        by WebConnectDialog since it creates its cookies before the login is actually complete.
+
+        This is recorded with a file in ~/.cache/lutris so it will persist across Lutris
+        restarted, just as the credentials themselves do. For this reason, we need to allow
+        the user to login again even when a login is in progress."""
+        return self._get_login_in_progress_path().exists()
+
+    @is_login_in_progress.setter
+    def is_login_in_progress(self, in_progress: bool) -> None:
+        path = self._get_login_in_progress_path()
+        if in_progress:
+            path.touch()
+        else:
+            path.unlink(missing_ok=True)
+
+    def _get_login_in_progress_path(self) -> Path:
+        return Path(os.path.join(settings.CACHE_DIR, f"{self.name}-login-in-progress"))
+
     def is_authenticated(self):
         """Return whether the service is authenticated"""
+        if self.is_login_in_progress:
+            logger.warning("Tried to get auth status while login in progress")
+            return False
         return all(system.path_exists(path) for path in self.credential_files)
 
     def wipe_game_cache(self):
@@ -454,7 +504,7 @@ class OnlineService(BaseService):
             except OSError:
                 logger.warning("Unable to remove %s", auth_file)
         logger.debug("logged out from %s", self.id)
-        self.emit("service-logout")
+        SERVICE_LOGOUT.fire(self)
 
     def load_cookies(self):
         """Load cookies from disk"""
