@@ -5,7 +5,6 @@ from gi.repository import Gio
 
 from lutris.database.games import get_game_by_field, get_games
 from lutris.game import Game
-from lutris.installer import get_installers
 from lutris.services.steam import SteamGame, SteamService
 from lutris.util import system
 from lutris.util.log import logger
@@ -34,8 +33,8 @@ class SteamWindowsService(SteamService):
             "name": db_game["name"],
             "version": self.name,
             "slug": slugify(db_game["name"]) + "-" + self.id,
-            "game_slug": slugify(db_game["name"]),
-            "runner": self.runner,
+            "game_slug": self.get_installed_slug(db_game),
+            "runner": self.get_installed_runner_name(db_game),
             "appid": db_game["appid"],
             "script": {
                 "requires": self.client_installer,
@@ -43,10 +42,13 @@ class SteamWindowsService(SteamService):
                     "exe": steam_game.config.game_config["exe"],
                     "args": "-no-cef-sandbox -applaunch %s" % db_game["appid"],
                     "prefix": steam_game.config.game_config["prefix"],
-                }
-            }
+                },
+            },
         }
 
+    def get_installed_runner_name(self, db_game):
+        return self.runner
+
     def get_steam(self):
         db_entry = get_game_by_field(self.client_installer, "installer_slug")
         if db_entry:
@@ -54,27 +56,22 @@ class SteamWindowsService(SteamService):
 
     def install(self, db_game):
         steam_game = self.get_steam()
-        if not steam_game:
-            installers = get_installers(
-                game_slug=self.client_installer,
-            )
-            appid = None
-        else:
-            installers = [self.generate_installer(db_game, steam_game)]
-            appid = db_game["appid"]
-            db_games = get_games(filters={"service_id": appid, "installed": "1", "service": self.id})
-            existing_game = self.match_existing_game(db_games, appid)
-            if existing_game:
-                logger.debug("Found steam game: %s", existing_game)
-                game = Game(existing_game.id)
-                game.save()
-                return
         application = Gio.Application.get_default()
-        application.show_installer_window(
-            installers,
-            service=self,
-            appid=appid
-        )
+        if not steam_game:
+            application.show_lutris_installer_window(game_slug=self.client_installer)
+            return
+
+        installers = [self.generate_installer(db_game, steam_game)]
+        appid = db_game["appid"]
+        db_games = get_games(filters={"service_id": appid, "installed": "1", "service": self.id})
+        existing_game = self.match_existing_game(db_games, appid)
+        if existing_game:
+            logger.debug("Found steam game: %s", existing_game)
+            game = Game(existing_game.id)
+            game.save()
+            return
+
+        application.show_installer_window(installers, service=self, appid=appid)
 
     @property
     def steamapps_paths(self):
