@@ -1,11 +1,12 @@
 """XrandR based display management"""
+
 import re
 import subprocess
 from collections import namedtuple
 
 from lutris.settings import DEFAULT_RESOLUTION_HEIGHT, DEFAULT_RESOLUTION_WIDTH
 from lutris.util.linux import LINUX_SYSTEM
-from lutris.util.log import logger, logging
+from lutris.util.log import logger
 from lutris.util.system import read_process_output
 
 Output = namedtuple("Output", ("name", "mode", "position", "rotation", "primary", "rate"))
@@ -13,21 +14,16 @@ Output = namedtuple("Output", ("name", "mode", "position", "rotation", "primary"
 
 def _get_vidmodes():
     """Return video modes from XrandR"""
-    logger.debug("Retrieving video modes from XrandR")
-    return read_process_output([LINUX_SYSTEM.get("xrandr")]).split("\n")
-
-
-def _log_vidmodes(message):
-    """Write the xrandr output to the log for debugging purposes"""
-    if logger.isEnabledFor(logging.DEBUG):
-        xrandr_output = read_process_output([LINUX_SYSTEM.get("xrandr")])
-        logger.debug("%s\n%s", message, xrandr_output)
+    xrandr_output = read_process_output([LINUX_SYSTEM.get("xrandr")]).split("\n")
+    logger.debug("Retrieving %s video modes from XrandR", len(xrandr_output))
+    return xrandr_output
 
 
 def get_outputs():  # pylint: disable=too-many-locals
     """Return list of namedtuples containing output 'name', 'geometry',
     'rotation' and whether it is the 'primary' display."""
     outputs = []
+    logger.debug("Retrieving display outputs")
     vid_modes = _get_vidmodes()
     position = None
     rotate = None
@@ -40,10 +36,10 @@ def get_outputs():  # pylint: disable=too-many-locals
         fields = line.split()
         if "connected" in fields[1:] and len(fields) >= 4:
             try:
-                connected_index = fields.index('connected', 1)
+                connected_index = fields.index("connected", 1)
                 name_fields = fields[:connected_index]
                 name = " ".join(name_fields)
-                data_fields = fields[connected_index + 1:]
+                data_fields = fields[connected_index + 1 :]
                 if data_fields[0] == "primary":
                     data_fields = data_fields[1:]
                 geometry, rotate, *_ = data_fields
@@ -55,8 +51,7 @@ def get_outputs():  # pylint: disable=too-many-locals
                 position = "{x_pos}x{y_pos}".format(x_pos=x_pos, y_pos=y_pos)
             except ValueError as ex:
                 logger.error(
-                    "Unhandled xrandr line %s, error: %s. "
-                    "Please send your xrandr output to the dev team", line, ex
+                    "Unhandled xrandr line %s, error: %s. " "Please send your xrandr output to the dev team", line, ex
                 )
                 continue
         elif "*" in line:
@@ -93,14 +88,15 @@ def turn_off_except(display):
 def get_resolutions():
     """Return the list of supported screen resolutions."""
     resolution_list = []
+    logger.debug("Retrieving resolution list")
     for line in _get_vidmodes():
         if line.startswith("  "):
             resolution_match = re.match(r".*?(\d+x\d+).*", line)
             if resolution_match:
                 resolution_list.append(resolution_match.groups()[0])
     if not resolution_list:
-        resolution_list = ['%dx%d' % (DEFAULT_RESOLUTION_WIDTH, DEFAULT_RESOLUTION_HEIGHT)]
-        _log_vidmodes("Unable to generate resolution list from xrandr output")
+        logger.error("Unable to generate resolution list from xrandr output")
+        return ["%sx%s" % (DEFAULT_RESOLUTION_WIDTH, DEFAULT_RESOLUTION_HEIGHT)]
     return sorted(set(resolution_list), key=lambda x: int(x.split("x")[0]), reverse=True)
 
 
@@ -119,10 +115,11 @@ def change_resolution(resolution):
         if resolution not in get_resolutions():
             logger.warning("Resolution %s doesn't exist.", resolution)
         else:
-            logger.info("Changing resolution to %s", resolution)
-            with subprocess.Popen([LINUX_SYSTEM.get("xrandr"), "-s", resolution]) as xrandr:
+            output_name = get_outputs()[0].name
+            logger.info("Changing resolution on %s to %s", output_name, resolution)
+            args = [LINUX_SYSTEM.get("xrandr"), "--output", output_name, "--mode", resolution]
+            with subprocess.Popen(args) as xrandr:
                 xrandr.communicate()
-
     else:
         for display in resolution:
             logger.debug("Switching to %s on %s", display.mode, display.name)
@@ -156,7 +153,6 @@ def change_resolution(resolution):
 
 
 class LegacyDisplayManager:  # pylint: disable=too-few-public-methods
-
     """Legacy XrandR based display manager.
     Does not work on Wayland.
     """
@@ -179,7 +175,7 @@ class LegacyDisplayManager:  # pylint: disable=too-few-public-methods
                 resolution_match = re.match(r".*?(\d+x\d+).*", line)
                 if resolution_match:
                     return resolution_match.groups()[0].split("x")
-        _log_vidmodes("Unable to find the current resolution from xrandr output")
+        logger.error("Unable to find the current resolution from xrandr output")
         return str(DEFAULT_RESOLUTION_WIDTH), str(DEFAULT_RESOLUTION_HEIGHT)
 
     @staticmethod
