@@ -141,13 +141,16 @@ class TestGetNvidiaDriverInfo(unittest.TestCase):
     )
     @patch("os.path.exists", return_value=True)
     def test_file_errors(self, mock_path_exists, mock_open):
-        with patch.object(drivers, "GlxInfo", return_value=FAKE_GLXINFO_NVIDIA), patch.object(
-            subprocess,
-            "run",
-            side_effect=[
-                subprocess.CompletedProcess([], 0, stdout="Linux\n"),
-                subprocess.CompletedProcess([], 0, stdout="x86_64\n"),
-            ],
+        with (
+            patch.object(drivers, "GlxInfo", return_value=FAKE_GLXINFO_NVIDIA),
+            patch.object(
+                subprocess,
+                "run",
+                side_effect=[
+                    subprocess.CompletedProcess([], 0, stdout="Linux\n"),
+                    subprocess.CompletedProcess([], 0, stdout="x86_64\n"),
+                ],
+            ),
         ):
             actual = drivers.get_nvidia_driver_info()
 
